@@ -23,13 +23,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 // Qt
 #include <QApplication>
-#include <QFuture>
-#include <QFutureWatcher>
-#include <QList>
-#include <QProgressDialog>
 #include <QStandardItemModel>
-#include <QtConcurrentMap>
-#include <QWidget>
+#include <QToolButton>
 
 // KDE
 #include <kfiledialog.h>
@@ -41,26 +36,32 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <kurl.h>
 
 // Local
+#include <lib/binder.h>
 #include <lib/document/documentfactory.h>
+#include <lib/document/documentjob.h>
+#include <lib/document/savejob.h>
 #include <lib/gwenviewconfig.h>
 #include <lib/historymodel.h>
+#include <lib/messagebubble.h>
 #include <lib/mimetypeutils.h>
 #include <lib/semanticinfo/semanticinfodirmodel.h>
 #include <lib/semanticinfo/sorteddirmodel.h>
 #include <lib/transformimageoperation.h>
+#include <mainwindow.h>
+#include <saveallhelper.h>
 
 namespace Gwenview {
 
 
 struct GvCorePrivate {
 	GvCore* q;
-	QWidget* mParent;
+	MainWindow* mMainWindow;
 	SortedDirModel* mDirModel;
 	HistoryModel* mRecentFoldersModel;
 	HistoryModel* mRecentUrlsModel;
 
 	bool showSaveAsDialog(const KUrl& url, KUrl* outUrl, QByteArray* format) {
-		KFileDialog dialog(url, QString(), mParent);
+		KFileDialog dialog(url, QString(), mMainWindow);
 		dialog.setOperationMode(KFileDialog::Saving);
 		dialog.setSelection(url.fileName());
 		dialog.setMimeFilter(
@@ -77,7 +78,7 @@ struct GvCorePrivate {
 			const QString mimeType = dialog.currentMimeFilter();
 			if (mimeType.isEmpty()) {
 				KMessageBox::sorry(
-					mParent,
+					mMainWindow,
 					i18nc("@info",
 						"No image format selected.")
 					);
@@ -90,7 +91,7 @@ struct GvCorePrivate {
 				break;
 			}
 			KMessageBox::sorry(
-				mParent,
+				mMainWindow,
 				i18nc("@info",
 					"Gwenview cannot save images as %1.", mimeType)
 				);
@@ -102,11 +103,11 @@ struct GvCorePrivate {
 };
 
 
-GvCore::GvCore(QWidget* parent, SortedDirModel* dirModel)
-: QObject(parent)
+GvCore::GvCore(MainWindow* mainWindow, SortedDirModel* dirModel)
+: QObject(mainWindow)
 , d(new GvCorePrivate) {
 	d->q = this;
-	d->mParent = parent;
+	d->mMainWindow = mainWindow;
 	d->mDirModel = dirModel;
 	d->mRecentFoldersModel = 0;
 	d->mRecentUrlsModel = 0;
@@ -160,122 +161,33 @@ void GvCore::addUrlToRecentUrls(const KUrl& url) {
 }
 
 
-struct SaveAllHelper {
-	typedef QPair<KUrl, QString> ErrorListItem;
-	typedef QList<ErrorListItem> ErrorList;
-
-	SaveAllHelper(ErrorList* errorList)
-	: mErrorList(errorList) {}
-
-	void operator()(Document::Ptr doc) {
-		KUrl url = doc->url();
-		if (!doc->save(url, doc->format())) {
-			*mErrorList << qMakePair(url, doc->errorString());
-		}
-	}
-
-	ErrorList* mErrorList;
-};
-
 void GvCore::saveAll() {
-	SaveAllHelper::ErrorList errorList;
-	SaveAllHelper helper(&errorList);
-
-	// Separate local and remote urls because saving to remote urls uses KIO
-	// methods, which are not thread-safe.
-	// We do not use a KUrl::List because DocumentFactory::load() is not
-	// thread-safe.
-	QList<Document::Ptr> localDocs;
-	QList<Document::Ptr> remoteDocs;
-
-	Q_FOREACH(const KUrl& url, DocumentFactory::instance()->modifiedDocumentList()) {
-		Document::Ptr doc = DocumentFactory::instance()->load(url);
-		if (url.isLocalFile()) {
-			localDocs << doc;
-		} else {
-			remoteDocs << doc;
-		}
-	}
-
-	QProgressDialog progress(d->mParent);
-	progress.setLabelText(i18nc("@info:progress saving all image changes", "Saving..."));
-	progress.setCancelButtonText(i18n("&Stop"));
-	progress.setMinimum(0);
-	progress.setMaximum(localDocs.size() + remoteDocs.size());
-	progress.setWindowModality(Qt::WindowModal);
-	progress.show();
-
-	// Save local urls
-	QFuture<void> future = QtConcurrent::map(localDocs, helper);
-
-	QFutureWatcher<void> watcher;
-	watcher.setFuture(future);
-	connect(&watcher, SIGNAL(progressValueChanged(int)),
-		&progress, SLOT(setValue(int)) );
-
-	connect(&progress, SIGNAL(canceled()),
-		&watcher, SLOT(cancel()) );
-
-	watcher.waitForFinished();
-
-	// Save remote urls
-	Q_FOREACH(Document::Ptr doc, remoteDocs) {
-		if (progress.wasCanceled()) {
-			break;
-		}
-		helper(doc);
-		progress.setValue(progress.value() + 1);
-		qApp->processEvents();
-	}
-
-	progress.close();
-
-	// Done, show message if necessary
-	if (errorList.count() > 0) {
-		QString msg = i18ncp("@info", "One document could not be saved:", "%1 documents could not be saved:", errorList.count());
-		msg += "<ul>";
-		Q_FOREACH(const SaveAllHelper::ErrorListItem& item, errorList) {
-			const KUrl& url = item.first;
-			QString name = url.fileName().isEmpty() ? url.pathOrUrl() : url.fileName();
-			msg += "<li>"
-				+ i18nc("@info %1 is the name of the document which failed to save, %2 is the reason for the failure",
-					"<filename>%1</filename>: %2", name, item.second)
-				+ "</li>";
-		}
-		msg += "</ul>";
-		KMessageBox::sorry(d->mParent, msg);
-	}
+	SaveAllHelper helper(d->mMainWindow);
+	helper.save();
 }
 
 
 void GvCore::save(const KUrl& url) {
 	Document::Ptr doc = DocumentFactory::instance()->load(url);
-	doc->loadFullImage();
-	doc->waitUntilLoaded();
 	QByteArray format = doc->format();
 	const QStringList availableTypes = KImageIO::types(KImageIO::Writing);
 	if (availableTypes.contains(QString(format))) {
-		if (!doc->save(url, format)) {
-			QString name = url.fileName().isEmpty() ? url.pathOrUrl() : url.fileName();
-			QString msg = i18nc("@info", "<b>Saving <filename>%1</filename> failed:</b><br>%2",
-				name, doc->errorString());
-			KMessageBox::sorry(d->mParent, msg);
+		DocumentJob* job = doc->save(url, format);
+		connect(job, SIGNAL(result(KJob*)), SLOT(slotSaveResult(KJob*)));
+	} else {
+		// We don't know how to save in 'format', ask the user for a format we can
+		// write to.
+		KGuiItem saveUsingAnotherFormat = KStandardGuiItem::saveAs();
+		saveUsingAnotherFormat.setText(i18n("Save using another format"));
+		int result = KMessageBox::warningContinueCancel(
+			d->mMainWindow,
+			i18n("Gwenview cannot save images in '%1' format.", QString(format)),
+			QString() /* caption */,
+			saveUsingAnotherFormat
+			);
+		if (result == KMessageBox::Continue) {
+			saveAs(url);
 		}
-		return;
-	}
-
-	// We don't know how to save in 'format', ask the user for a format we can
-	// write to.
-	KGuiItem saveUsingAnotherFormat = KStandardGuiItem::saveAs();
-	saveUsingAnotherFormat.setText(i18n("Save using another format"));
-	int result = KMessageBox::warningContinueCancel(
-		d->mParent,
-		i18n("Gwenview cannot save images in '%1' format.", QString(format)),
-		QString() /* caption */,
-		saveUsingAnotherFormat
-		);
-	if (result == KMessageBox::Continue) {
-		saveAs(url);
 	}
 }
 
@@ -288,9 +200,9 @@ void GvCore::saveAs(const KUrl& url) {
 	}
 
 	// Check for overwrite
-	if (KIO::NetAccess::exists(saveAsUrl, KIO::NetAccess::DestinationSide, d->mParent)) {
+	if (KIO::NetAccess::exists(saveAsUrl, KIO::NetAccess::DestinationSide, d->mMainWindow)) {
 		int answer = KMessageBox::warningContinueCancel(
-			d->mParent,
+			d->mMainWindow,
 			i18nc("@info",
 				"A file named <filename>%1</filename> already exists.\n"
 				"Are you sure you want to overwrite it?",
@@ -304,18 +216,55 @@ void GvCore::saveAs(const KUrl& url) {
 
 	// Start save
 	Document::Ptr doc = DocumentFactory::instance()->load(url);
-	doc->save(saveAsUrl, format.data());
+	KJob* job = doc->save(saveAsUrl, format.data());
+	connect(job, SIGNAL(result(KJob*)), SLOT(slotSaveResult(KJob*)));
 }
 
 
 static void applyTransform(const KUrl& url, Orientation orientation) {
-	if (!GvCore::ensureDocumentIsEditable(url)) {
-		return;
-	}
 	TransformImageOperation* op = new TransformImageOperation(orientation);
 	Document::Ptr doc = DocumentFactory::instance()->load(url);
-	op->setDocument(doc);
-	doc->undoStack()->push(op);
+	op->applyToDocument(doc);
+}
+
+
+void GvCore::slotSaveResult(KJob* _job) {
+	SaveJob* job = static_cast<SaveJob*>(_job);
+	KUrl oldUrl = job->oldUrl();
+	KUrl newUrl = job->newUrl();
+
+	if (job->error()) {
+		QString name = newUrl.fileName().isEmpty() ? newUrl.pathOrUrl() : newUrl.fileName();
+		QString msg = i18nc("@info", "<b>Saving <filename>%1</filename> failed:</b><br>%2",
+			name, job->errorString());
+
+		int result = KMessageBox::warningContinueCancel(
+			d->mMainWindow, msg,
+			QString() /* caption */,
+			KStandardGuiItem::saveAs());
+
+		if (result == KMessageBox::Continue) {
+			saveAs(newUrl);
+		}
+		return;
+	}
+
+	if (oldUrl != newUrl) {
+		d->mMainWindow->goToUrl(newUrl);
+
+		MessageBubble* bubble = new MessageBubble();
+		bubble->setText(i18n("You are now viewing the new document."));
+		KGuiItem item = KStandardGuiItem::back();
+		item.setText(i18n("Go back to the original"));
+		QToolButton* button = bubble->addButton(item);
+
+		connect(button, SIGNAL(clicked()),
+			CREATE_BINDER(bubble, MainWindow, KUrl, d->mMainWindow, goToUrl, oldUrl), SLOT(run()));
+		connect(button, SIGNAL(clicked()),
+			bubble, SLOT(deleteLater()));
+
+		d->mMainWindow->showMessageBubble(bubble);
+	}
 }
 
 
@@ -340,8 +289,10 @@ void GvCore::setRating(const KUrl& url, int rating) {
 
 
 bool GvCore::ensureDocumentIsEditable(const KUrl& url) {
+	// FIXME: Replace with a CheckEditableJob?
+	// This way we can factorize the error message
 	Document::Ptr doc = DocumentFactory::instance()->load(url);
-	doc->loadFullImage();
+	doc->startLoadingFullImage();
 	doc->waitUntilLoaded();
 	if (doc->isEditable()) {
 		return true;
