@@ -60,7 +60,7 @@ namespace Gwenview {
 #undef LOG
 //#define ENABLE_LOG
 #ifdef ENABLE_LOG
-#define LOG(x) kDebug() << x << endl
+#define LOG(x) kDebug() << x
 #else
 #define LOG(x) ;
 #endif
@@ -201,15 +201,19 @@ void ThumbnailThread::run() {
 			QMutexLocker lock(&mMutex);
 			Q_ASSERT(!mPixPath.isNull());
 			LOG("Loading" << mPixPath);
-			loadThumbnail();
+			bool needCaching;
+			bool ok = loadThumbnail(&needCaching);
+			if (ok && needCaching) {
+				cacheThumbnail();
+			}
 			mPixPath.clear(); // done, ready for next
 		}
 		if(testCancel()) {
 			return;
 		}
 		{
-			LOG("emitting done signal");
 			QSize size(mOriginalWidth, mOriginalHeight);
+			LOG("emitting done signal, size=" << size);
 			QMutexLocker lock(&mMutex);
 			done(mImage, size);
 			LOG("Done");
@@ -218,9 +222,9 @@ void ThumbnailThread::run() {
 	LOG("Ending thread");
 }
 
-void ThumbnailThread::loadThumbnail() {
+bool ThumbnailThread::loadThumbnail(bool* needCaching) {
 	mImage = QImage();
-	bool needCaching=true;
+	*needCaching = true;
 	int pixelSize = ThumbnailGroup::pixelSize(mThumbnailGroup);
 	Orientation orientation = NORMAL;
 
@@ -229,71 +233,83 @@ void ThumbnailThread::loadThumbnail() {
 	if (reader.format() == "jpeg") {
 		JpegContent content;
 		content.load(mPixPath);
-		mOriginalWidth = content.size().width();
-		mOriginalHeight = content.size().height();
 		QImage thumbnail = content.thumbnail();
 		orientation = content.orientation();
 
 		if (qMax(thumbnail.width(), thumbnail.height()) >= pixelSize) {
 			mImage = thumbnail;
-			needCaching = false;
+			if (orientation != NORMAL && orientation != NOT_AVAILABLE) {
+				QMatrix matrix = ImageUtils::transformMatrix(orientation);
+				mImage = mImage.transformed(matrix);
+			}
+			mOriginalWidth = content.size().width();
+			mOriginalHeight = content.size().height();
+			return true;
 		}
 	}
 
 	// Generate thumbnail from full image
-	if (mImage.isNull()) {
-		QSize originalSize = reader.size();
-		if (originalSize.isValid() && reader.supportsOption(QImageIOHandler::ScaledSize)) {
-			int scale;
-			const int maxSize = qMax(originalSize.width(), originalSize.height());
-			for (scale=1; pixelSize*scale*2 <= maxSize && scale <= 8; scale *= 2) {}
-			const QSize scaledSize = originalSize / scale;
-			if (!scaledSize.isEmpty()) {
-				reader.setScaledSize(scaledSize);
-			}
-		}
-
-		QImage originalImage;
-		// format() is empty after QImageReader::read() is called
-		QByteArray format = reader.format();
-		if (reader.read(&originalImage)) {
-			if (!originalSize.isValid()) {
-				originalSize = originalImage.size();
-			}
-			mOriginalWidth = originalSize.width();
-			mOriginalHeight = originalSize.height();
-
-			if (qMax(mOriginalWidth, mOriginalHeight)<=pixelSize) {
-				mImage=originalImage;
-				needCaching = format != "png";
-			} else {
-				mImage = originalImage.scaled(pixelSize, pixelSize, Qt::KeepAspectRatio);
-			}
+	QSize originalSize = reader.size();
+	if (originalSize.isValid() && reader.supportsOption(QImageIOHandler::ScaledSize)) {
+		int scale;
+		const int maxSize = qMax(originalSize.width(), originalSize.height());
+		for (scale=1; pixelSize*scale*2 <= maxSize && scale <= 8; scale *= 2) {}
+		const QSize scaledSize = originalSize / scale;
+		if (!scaledSize.isEmpty()) {
+			reader.setScaledSize(scaledSize);
 		}
 	}
 
-	if (mImage.isNull()) {
+	QImage originalImage;
+	// format() is empty after QImageReader::read() is called
+	QByteArray format = reader.format();
+	if (!reader.read(&originalImage)) {
 		kWarning() << "Could not generate thumbnail for file" << mOriginalUri;
-		return;
+		return false;
+	}
+	if (!originalSize.isValid()) {
+		originalSize = originalImage.size();
+	}
+	mOriginalWidth = originalSize.width();
+	mOriginalHeight = originalSize.height();
+
+	if (qMax(mOriginalWidth, mOriginalHeight)<=pixelSize) {
+		mImage = originalImage;
+		*needCaching = format != "png";
+	} else {
+		mImage = originalImage.scaled(pixelSize, pixelSize, Qt::KeepAspectRatio);
 	}
 
 	// Rotate if necessary
 	if (orientation != NORMAL && orientation != NOT_AVAILABLE) {
 		QMatrix matrix = ImageUtils::transformMatrix(orientation);
 		mImage = mImage.transformed(matrix);
-	}
 
-	if (needCaching) {
-		mImage.setText("Thumb::Uri"          , 0, mOriginalUri);
-		mImage.setText("Thumb::MTime"        , 0, QString::number(mOriginalTime));
-		mImage.setText("Thumb::Size"         , 0, QString::number(mOriginalSize));
-		mImage.setText("Thumb::Mimetype"     , 0, mOriginalMimeType);
-		mImage.setText("Thumb::Image::Width" , 0, QString::number(mOriginalWidth));
-		mImage.setText("Thumb::Image::Height", 0, QString::number(mOriginalHeight));
-		mImage.setText("Software"            , 0, "Gwenview");
-
-		emit thumbnailReadyToBeCached(mThumbnailPath, mImage);
+		switch (orientation) {
+		case TRANSPOSE:
+		case ROT_90:
+		case TRANSVERSE:
+		case ROT_270:
+			qSwap(mOriginalWidth, mOriginalHeight);
+			break;
+		default:
+			break;
+		}
 	}
+	return true;
+}
+
+
+void ThumbnailThread::cacheThumbnail() {
+	mImage.setText("Thumb::Uri"          , 0, mOriginalUri);
+	mImage.setText("Thumb::MTime"        , 0, QString::number(mOriginalTime));
+	mImage.setText("Thumb::Size"         , 0, QString::number(mOriginalSize));
+	mImage.setText("Thumb::Mimetype"     , 0, mOriginalMimeType);
+	mImage.setText("Thumb::Image::Width" , 0, QString::number(mOriginalWidth));
+	mImage.setText("Thumb::Image::Height", 0, QString::number(mOriginalHeight));
+	mImage.setText("Software"            , 0, "Gwenview");
+
+	emit thumbnailReadyToBeCached(mThumbnailPath, mImage);
 }
 
 
@@ -367,7 +383,7 @@ ThumbnailLoadJob::ThumbnailLoadJob(const KFileItemList& items, ThumbnailGroup::E
 , mState( STATE_NEXTTHUMB )
 , mThumbnailGroup(group)
 {
-	LOG((int)this);
+	LOG(this);
 
 	// Make sure we have a place to store our thumbnails
 	QString thumbnailDir = ThumbnailLoadJob::thumbnailBaseDir(mThumbnailGroup);
@@ -389,7 +405,7 @@ ThumbnailLoadJob::ThumbnailLoadJob(const KFileItemList& items, ThumbnailGroup::E
 
 
 ThumbnailLoadJob::~ThumbnailLoadJob() {
-	LOG((int)this);
+	LOG(this);
 	if (hasSubjobs()) {
 		LOG("Killing subjob");
 		KJob* job = subjobs().first();
@@ -459,7 +475,7 @@ void ThumbnailLoadJob::removeItems(const KFileItemList& itemList) {
 
 
 void ThumbnailLoadJob::determineNextIcon() {
-	LOG((int)this);
+	LOG(this);
 	mState = STATE_NEXTTHUMB;
 
 	// No more items ?
@@ -484,7 +500,7 @@ void ThumbnailLoadJob::determineNextIcon() {
 	bool directStatOk = false;
 	if (UrlUtils::urlIsFastLocalFile(mCurrentUrl)) {
 		KDE_struct_stat buff;
-		if ( KDE_stat( QFile::encodeName(mCurrentUrl.path()), &buff ) == 0 )  {
+		if ( KDE::stat( mCurrentUrl.toLocalFile(), &buff ) == 0 )  {
 			directStatOk = true;
 			mOriginalTime = buff.st_mtime;
 			QTimer::singleShot( 0, this, SLOT( checkThumbnail()));
@@ -496,7 +512,7 @@ void ThumbnailLoadJob::determineNextIcon() {
 		LOG( "KIO::stat orig" << mCurrentUrl.url() );
 		addSubjob(job);
 	}
-	LOG("/determineNextIcon" << (int)this);
+	LOG("/determineNextIcon" << this);
 }
 
 
