@@ -38,7 +38,7 @@ namespace Gwenview {
 class ThumbnailView;
 
 
-class PreviewItemDelegatePrivate;
+struct PreviewItemDelegatePrivate;
 
 /**
  * An ItemDelegate which generates thumbnails for images. It also makes sure
@@ -57,9 +57,11 @@ public:
 	};
 
 	enum ThumbnailDetail {
-		FileNameDetail = 1,
-		DateDetail     = 2,
-		RatingDetail   = 4
+		FileNameDetail  = 1,
+		DateDetail      = 2,
+		RatingDetail    = 4,
+		ImageSizeDetail = 8,
+		FileSizeDetail  = 16
 	};
 	// FIXME: Find out why this cause problems with Qt::Alignment in
 	// PreviewItemDelegate!
@@ -105,7 +107,7 @@ protected:
 
 private:
 	PreviewItemDelegatePrivate* const d;
-	friend class PreviewItemDelegatePrivate;
+	friend struct PreviewItemDelegatePrivate;
 };
 
 
