@@ -110,7 +110,7 @@ static void adaptSizeToResolution( TIFF *tiff, ttag_t whichres, double dpi, uint
     float resvalue = 1.0;
     uint16 resunit = 0;
     if ( !TIFFGetField( tiff, whichres, &resvalue )
-         || !TIFFGetField( tiff, TIFFTAG_RESOLUTIONUNIT, &resunit ) )
+         || !TIFFGetFieldDefaulted( tiff, TIFFTAG_RESOLUTIONUNIT, &resunit ) )
         return;
 
     float newsize = *size / resvalue;
@@ -164,7 +164,7 @@ static KAboutData createAboutData()
          "okular_tiff",
          "okular_tiff",
          ki18n( "TIFF Backend" ),
-         "0.2.3",
+         "0.2.4",
          ki18n( "A TIFF backend" ),
          KAboutData::License_GPL,
          ki18n( "© 2006-2008 Pino Toscano" ),
@@ -266,8 +266,6 @@ QImage TIFFGenerator::image( Okular::PixmapRequest * request )
         uint32 orientation = 0;
         TIFFGetField( d->tiff, TIFFTAG_IMAGEWIDTH, &width );
         TIFFGetField( d->tiff, TIFFTAG_IMAGELENGTH, &height );
-        if ( rotation % 2 == 1 )
-            qSwap( width, height );
 
         if ( !TIFFGetField( d->tiff, TIFFTAG_ORIENTATION, &orientation ) )
             orientation = ORIENTATION_TOPLEFT;
@@ -354,6 +352,9 @@ void TIFFGenerator::loadPages( QVector<Okular::Page*> & pagesVector )
     uint32 width = 0;
     uint32 height = 0;
 
+    const double dpiX = Okular::Utils::dpiX();
+    const double dpiY = Okular::Utils::dpiY();
+
     for ( tdir_t i = 0; i < dirs; ++i )
     {
         if ( !TIFFSetDirectory( d->tiff, i ) )
@@ -363,8 +364,8 @@ void TIFFGenerator::loadPages( QVector<Okular::Page*> & pagesVector )
              TIFFGetField( d->tiff, TIFFTAG_IMAGELENGTH, &height ) != 1 )
             continue;
 
-        adaptSizeToResolution( d->tiff, TIFFTAG_XRESOLUTION, Okular::Utils::dpiX(), &width );
-        adaptSizeToResolution( d->tiff, TIFFTAG_YRESOLUTION, Okular::Utils::dpiY(), &height );
+        adaptSizeToResolution( d->tiff, TIFFTAG_XRESOLUTION, dpiX, &width );
+        adaptSizeToResolution( d->tiff, TIFFTAG_YRESOLUTION, dpiY, &height );
 
         Okular::Page * page = new Okular::Page( realdirs, width, height, readTiffRotation( d->tiff ) );
         pagesVector[ realdirs ] = page;
@@ -385,6 +386,7 @@ bool TIFFGenerator::print( QPrinter& printer )
     QPainter p( &printer );
 
     QList<int> pageList = Okular::FilePrinter::pageList( printer, document()->pages(),
+                                                         document()->currentPage() + 1,
                                                          document()->bookmarkedPageList() );
 
     for ( tdir_t i = 0; i < pageList.count(); ++i )
